@@ -6,8 +6,8 @@ use crate::matrix::Matrix;
 fn basic() {
     let mut matrix = Matrix::<i32>::new((5, 5));
 
-    matrix.set(1, (1, 1));
-    matrix.set(6, (1, 2));
+    assert!(matrix.set(1, (1, 1)).is_ok());
+    assert!(matrix.set(6, (1, 2)).is_ok());
 
     let a = matrix.get((1, 1)).unwrap();
     let b = matrix.get((1, 2)).unwrap();
@@ -37,3 +37,12 @@ fn translation() {
     assert_eq!(matrix.get((0,0)), None);
     assert_eq!(matrix.get((1,0)), Some(1));
 }
+
+#[test]
+fn out_of_bounds() {
+    let mut matrix = Matrix::<bool>::new((5,5));
+
+    assert!(matrix.set(true, (0,0)).is_ok());
+    assert!(matrix.translate((0,0), (0,1)).is_ok());
+    assert!(matrix.delete((5,5)).is_err());
+}
\ No newline at end of file
